@@ -10,9 +10,9 @@ $, = "\n\t";
 # export @binz after looking for */bin, override the 
 #  "ignore" to search /bin, /usr/bin.
 
-use FindBin::libs qw( export );
-use FindBin::libs qw( export=found base=blib );
-use FindBin::libs qw( export=binz base=bin ignore=foo,bar );
+use FindBin::libs qw( noprint export );
+use FindBin::libs qw( print export=found base=blib );
+use FindBin::libs qw( print export=binz base=bin ignore=foo,bar );
 
 use Test::Simple tests => 6;
 
@@ -22,6 +22,6 @@ ok( @binz,  '@binz exported' );
 
 ok( $lib[0]   eq "$FindBin::Bin/lib", "Found $FindBin::Bin/lib" );
 ok( $found[0] eq "$FindBin::Bin/blib","Found $FindBin::Bin/blib" );
-ok( $binz[-1] eq "/bin",              "Found /bin" );
+ok( $binz[-1] =~ m{/bin$},             "Found */bin" );
 
 exit 0;
